#!/usr/bin/env python
# -*- coding: utf-8 -*-

import gtk
import gtk.gdk
import pango

from libvisioo.GLOBALS import sep, TEMP_EXTRACT_DIR, PICS_PATH


class Draw (gtk.DrawingArea) :
	def __init__(self, x, y):
		gtk.DrawingArea.__init__ (self)
		self.pangolayout = self.create_pango_layout("")
		self.set_events(gtk.gdk.POINTER_MOTION_MASK | gtk.gdk.POINTER_MOTION_HINT_MASK )
		self.set_size_request(x, y)
		self.colormap = gtk.gdk.Colormap(gtk.gdk.visual_get_system(), True)
		self.show()

	def expose_area(self, area, event):
		self.area_style = self.get_style()
		self.gc = self.area_style.fg_gc[gtk.STATE_NORMAL]
		return True

	def set_size_pixel (self, size):
		if size[0] : x = int(size[0])
		else : x = 0

		if size[1] : y = int(size[1])
		else : y = 0

		self.set_size_request(x, y)

	def draw_point(self, pt):
		self.window.draw_point(self.gc, pt[0], pt[1])
		return

	def draw_points(self, pts):
		self.window.draw_points(self.gc, pts)
		return

	def draw_lines(self, pts):
		self.window.draw_lines(self.gc, pts)
		return

	def draw_line(self, pt1, pt2):
		self.window.draw_line(self.gc, pt1[0], pt1[1], pt2[0], pt2[1])
		return

	def draw_rectangle(self, pt1, size, fill = True):
		self.window.draw_rectangle(self.gc, fill, int(pt1[0]), int(pt1[1]), int(size[0]), int(size[1]))
		return

	def draw_arcs(self, center, ray, fill = False, angle = (0,360*64)):
		self.window.draw_arc(self.gc, fill, \
		center[0], center[1], ray[0], ray[1], angle[0]*64, angle[1]*64)
		return

	def draw_pixmap(self, pt):
		pixmap, mask = gtk.gdk.pixmap_create_from_xpm(
			self.window, self.area_style.bg[gtk.STATE_NORMAL], "gtk.xpm")

		self.window.draw_drawable(self.gc, pixmap, 0, 0, pt[0], pt[1], -1, -1)
		self.pangolayout.set_text("Pixmap")
		self.window.draw_layout(self.gc, x+5, y+80, self.pangolayout)
		return

	def draw_polygon(self, pts):
		self.window.draw_polygon(self.gc, True, pts)
		return
