# -*- coding: utf-8 -*-

import libvisioo.oofichier as oofichier
import libvisioo.ooborders as ooborders
# from libvisioo.oodefault_borders import *

class OOCell :
	""" Cellule de tableau OpenOffice """
	def __init__ (self) :
		#INFO CELLULE
		self.style_name = "" #nom du style
		self.name = "" #nom de la cellule

		self.style = None #style OOStyle
		self.num = None #num cellule
		self.row = None #num ligne
		self.col = None #num colonne

		self.width = 0 #largeur cellule
		self.height = 20 #hauteur cellule


		# taille de la partie commune entre les cellules
		# généralement epaisseur de la bordure la plus exterieure
		self.inter_row = 1 # entre les lignes
		self.inter_col = 1 # entre les colonnes


		self.size = (0, 0) # taille de la cellule en px
		self.set_width(self.width)

		# bordure
		self.top = [(1,1)]
		self.bottom = [(1,1)]
		self.left = [(1,1)]
		self.right = [(1,1)]
		self.same_border = True

		# remplissage
		self.zonetexte = None #eventuelle zonetexte de type ui
		self.texte = "" #texte brut de la cellule

		self.justification = None #type ui.wrap
		self.padding = 10

	def set_width (self, width):
		self.width = width
		self.size = (self.width, self.height)

	def set_height (self, height):
		self.height = height
		self.size = (self.width, self.height)

	def get_size (self):
		return self.size

	def set_oostyle (self, style):
		""" pass oostyle, only fo:border and fo:padding read """
		self.style = style
		self.padding = self.style.get_property("fo:padding")
		self.padding = oofichier.oo2px(self.padding)

		border = self.style.get_property("fo:border")

		if not border :
			top = self.style.get_property("fo:border-top")
			bottom = self.style.get_property("fo:border-bottom")
			right = self.style.get_property("fo:border-rigth")
			left = self.style.get_property("fo:border-left")

			self.set_top_border_style(ooborders.convert_border(top))
			self.set_bottom_border_style(ooborders.convert_border(bottom))
			self.set_left_border_style(ooborders.convert_border(left))
			self.set_right_border_style(ooborders.convert_border(right))

		else : self.set_border_style(ooborders.convert_border(border))

	def set_border_style (self, border):
		""" border type : [(1,1),(0,2),...]
		nb 1 : style de remplissage / fill style
		nb 2 : epaisseur du trait / line width
		"""
		self.top = border
		self.bottom = border
		self.left = border
		self.right = border
		self.same_border = True
		self.inter_row = border[0][1]
		self.inter_col = border[0][1]

	def set_left_border_style (self, border):
		self.left = border
		self.same_border = False

	def set_right_border_style (self, border):
		self.right = border
		self.same_border = False
		self.inter_row = border[0][1]

	def set_top_border_style (self, border):
		self.top = border
		self.same_border = False

	def set_bottom_border_style (self, border):
		self.bottom = border
		self.same_border = False
		self.inter_col = border[0][1]

	def get_borders_style (self):
		return self.top, self.bottom, self.left, self.right

	def set_uizonetexte (self, zonetexte):
		self.zonetexte = zonetexte

	def set_texte (self, texte):
		self.texte = texte


""" EXEMPLES - EXAMPLES """

CELL_EMPTY = OOCell()

CELL_DEMO = OOCell()
CELL_DEMO.set_width(100)
CELL_DEMO.set_border_style ([(1,3),(0,2),(1,1)])


