# -*- coding: utf-8 -*-


import libvisioo.oofichier as oofichier
import libvisioo.ooloader as ooloader
import libvisioo.oostyles as oostyles
import libvisioo.ootable as ootable
import libvisioo.oocell as oocell

#####################################################################
# fr : ELEMENTS COMMUNS A TOUS LES TYPES DE FICHIERS OPENOFFICE     #
# en : COMMONS ELEMENT FOR ALL OPENOFFICE FILES TYPE                #
#####################################################################


class OOOVar :
	""" Toutes les variables utilisées par les classes Content et Styles

	Typographie
	self.NOM_MAJUSCULE valeur balise : True si traitement en cours, False par défaut
	Le nom corespond à la balise OpenOffice, les ":" et "-" sont remplacés par "_"
	self.tmp_nom_minuscule : variable temporaire de traitement comme le nom ou les proprietés des styles

	Voir code source pour les noms de variables
	"""
	def __init__ (self, ui_name):
		""" initialisation de toutes les variables """
		self.ui=ooloader.load_ui(ui_name)
		self.verbose = False

		self.BODY = False
		self.TABLE = False

		self.OFFICE_AUTOMATIC_STYLES = False
		self.OFFICE_DOCUMENT_STYLES = False
		self.OFFICE_FONT_FACE_DECLS = False
		self.OFFICE_MASTER_STYLES = False
		self.OFFICE_STYLES = False

		self.STYLE_BACKGROUND_IMAGE = False
		self.STYLE_COLUMNS = False
		self.STYLE_DEFAULT_STYLE = False
		self.STYLE_FONT_FACE = False
		self.STYLE_FOOTER = False
		self.STYLE_FOOTER_LEFT = False
		self.STYLE_FOOTER_STYLE = False
		self.STYLE_NOTE_SEP = False
		self.STYLE_GRAPHIC_PROPERTIES = False
		self.STYLE_HEADER_FOOTER_PROPERTIES = False
		self.STYLE_HEADER_STYLE = False
		self.STYLE_LIST_LEVEL_PROPERTIES = False
		self.STYLE_MASTER_PAGE = False
		self.STYLE_PAGE_LAYOUT = False
		self.STYLE_PAGE_LAYOUT_PROPERTIES = False
		self.STYLE_PARAGRAPH_PROPERTIES = False
		self.STYLE_STYLE = False
		self.STYLE_TAB_STOP = False
		self.STYLE_TAB_STOPS = False
		self.STYLE_TABLE_PROPERTIES = False
		self.STYLE_TABLE_ROW_PROPERTIES = False
		self.STYLE_TEXT_PROPERTIES = False

		self.TEXT_LINENUMBERING_CONFIGURATION = False
		self.TEXT_LIST_LEVEL_STYLE_BULLET = False
		self.TEXT_LIST_LEVEL_STYLE_NUMBER = False
		self.TEXT_LIST_STYLE = False
		self.TEXT_NOTES_CONFIGURATION = False
		self.TEXT_OUTLINE_LEVEL_STYLE = False
		self.TEXT_OUTLINE_STYLE = False
		self.TEXT_PAGE_NUMBER = False
		self.TEXT_TAB = False

		self.TEXT_H = False #header
		self.TEXT_LIST_ITEM = 0
		self.TEXT_LIST = False


		self.TEXT_S = False
		self.TEXT_P = False
		self.TEXT_SPAN = False

		self.STYLE_TYPE = False #balise type style:type, ex style:text-properties


		self.LIST_ZONETEXTE = [] # contient toutes les zonetexte excepté header, footer, notes

		self.NOTE_CONTENT = self.ui.ZoneTexte()

		self.HEADER_CONTENT = self.ui.ZoneTexte()
		self.HEADER_CONTENT.def_wrap_mode("WRAP_NONE")

		self.FOOTER_CONTENT = self.ui.ZoneTexte()
		self.FOOTER_CONTENT.def_wrap_mode("WRAP_NONE")


		self.NOTES = [] #listes des notes (normalement en bas de page)

		self.NOTE = False
		self.NOTE_CITATION = False
		self.NOTE_BODY = False

		self.HEADER = False # [Style]
		self.FOOTER = False # [Style]

		self.AUTOMATIC_STYLES = False #office:automatic-styles

		self.tmp_nom_textp_style = None # nom du style Pn
		self.tmp_nom_textspan_style = None # nom du style Tn
		self.tmp_nom_style = None #Nom du style

		self.tmp_textp_style = oostyles.OOStyle()
		self.tmp_textspan_style = oostyles.OOStyle()
		self.tmp_texth_style = oostyles.OOStyle()
		self.tmp_textfinal_style = oostyles.OOStyle()
		self.tmp_instance_style = oostyles.OOStyle()
		self.tmp_ordered_list_style = oostyles.OOStyle()
		self.tmp_unordered_list_style = oostyles.OOStyle()

		self.NOTE_CONTENT = self.ui.ZoneTexte('notes')

		note_style = oostyles.OOStyle("note_style")
		note_style.add_prop(('fo:color','#000099'))
		note_style.add_prop(('fo:font-size','16pt'))
		note_style.add_prop(('fo:text-align','center'))

		self.STYLE_NOTES = oostyles.OOStyle("note_style")
		self.STYLE_NOTES.add_prop(("style:text-background-color","#FFFF60"))
		self.STYLE_NOTES.add_prop(("fo:color","#FF0000"))

		self.STYLE_NOTES_CONTENT = oostyles.OOStyle("note_style")
		self.STYLE_NOTES_CONTENT.add_prop(("style:text-background-color","#FFFF60"))
		self.STYLE_NOTES_CONTENT.add_prop(("style:text-position", "super 58%"))

		self.NOTE_CONTENT.texte(self.ui.linebrk)
		self.NOTE_CONTENT.texte_oo(_("Notes"), note_style)
		self.NOTE_CONTENT.texte(2*self.ui.linebrk)
		self.NOTE_CONTENT.def_wrap_mode("WRAP_WORD")

		self.tmp_table = ootable.OOTable()
		self.tmp_cell = oocell.OOCell()

		self.tmp_style_properties = [] #liste de proprietes de styles de type UI

		self.dico_styles = {}
		#dico "nom du style ooo" -> "liste de style"
		#ex : {"p2":<instance oostyle>}
		self.dico_imgs = {}
		#dico nom images openoffice > nouveau nom
		#ex : 1000000000000222000000BFFCC332C7.png -> 1.png

	def set_verbose (self, boolean):
		self.verbose = boolean
