# -*- coding: utf-8 -*-

import libvisioo.oofichier as oofichier
import libvisioo.oocell as oocell
# import libvisioo.oodicos as oodicos

class OOTable :
	""" Gestion des tableaux OpenOffice
		Table Handler
	"""
	def __init__ (self, name="") :
		self.table = [[]] #list(table) of list (rows/lignes) of cell oocell
		self.style = None
		self.name = name

		self.rows = 0 #nb of rows/lignes
		self.cols = 0 #nb of col
		self.width = 0 #(px)
		self.height = 100 #(px)
		self.rows_height = [] #list de hauteurs (px) des lignes ex : 20,20,30
		self.cols_width = []

		self.inter_row = 1 #entre les lignes
		self.inter_col = 1

		self.size = (self.width, self.height)

	def set_name (self, name) :
		self.name = name

	def set_oostyle (self, style) :
		""" style : oostyle type table """
		self.style = style

		size = oofichier.oo2px (self.style.get_property("style:width"))
		self.set_width(size)

	def set_width (self, width):
		self.width = width
		self.size = (self.width, self.height)


	def set_table_size (self, size):
		""" size : (row, col)
		ATTENTION vide toutes les cellules
		WARNING clear all cells
		"""
		self.table = []
		for x in xrange(size[0]) :
			self.table.append([])
			self.rows_height.append(0)
			for y in xrange(0, size[1]) :
				self.table[x].append(None)

		for y in xrange(size[1]) :
			self.cols_width.append(0)

	def get_table_size (self):
		""" return table size : (rows, cols)"""
		self.rows = len(self.table)

		if self.rows : self.cols = len(self.table[0])
		else : self.cols = 0

		return (self.rows, self.cols)

	def get_size (self):
		""" return table size in pixels : (width, height) """
		return (int(self.size[0]), int(self.size[1]))


	def add_row (self):
		self.table.append([None]*self.cols)
		self.rows_height.append(0)
		self.get_table_size()

	def add_col (self, oostyle = None):
		self.cols += 1
		for x in xrange(0, len(self.table)) :
			self.table[x].append(None)

		width = 0
		if oostyle : width = oofichier.oo2px(oostyle.get_property("style:column-width"))
		self.cols_width.append(width)
# 		print width, "->", self.cols_width

		self.get_table_size()


	def set_cell (self, cell, location):
		""" ajoute/add cell [type : OOCell] at location [type : (n,n)]"""
		self.table[location[0]][location[1]] = cell
		self.rows_height[location[0]] = cell.height
		self.inter_row = cell.inter_row
		self.inter_col = cell.inter_col

	def add_cell (self, oocell):
		""" ajoute la cellule oocell dans la première case vide """
		size = self.get_table_size ()
		end = False
		for x in xrange(size[0]) :
			if end : break
			for y in xrange(0, size[1]) :
				if not self.table[x][y] :
					self.table[x][y] = oocell
					end = True
					break


	def get_cell (self, location) :
		""" return OOCell in location None if not found"""
		self.table[location[0]][location[1]]

	def get_cells (self):
		""" return list of cells"""
		return self.table

	def end_table (self):
		""" recalcule toutes les mesures du tableau
		calc again all table sizes """


		try : i = self.table.index([None]*self.cols)
		except : pass
		else : del self.table[i]

		cr = 0
		for row in self.table :
			cc = 0
			for cell in row :
				if not cell : self.table[cr][cc] = oocell.OOCell()
				else : cell.width = self.cols_width[cc]
				cc += 1
			cr += 1

		cpt = 0
		for row in self.table :

			width = 0
			number = 0
			i = 0

			while i < len(row):
				if not row[i] : row[i] = oocell.OOCell()
				i += 1

			for cell in row :
				if cell.width : width += cell.width
				elif self.cols_width[cpt] :
					width += self.cols_width[cpt]
					cell.set_width(self.cols_width[cpt])
				else : number += 1

			if number :
				cellwidth = (self.width - width)/number
				for cell in row :
					if not cell.width : cell.set_width(cellwidth)




""" EXEMPLES - EXAMPLES """

TABLE_EMPTY = OOTable()
